--[[
TimedVisibility

Script to show objects between the given 'eveningTime' and 'morningTime' in the xmlFile

@Author:	Ifko[nator]
@Date:		01.01.2018

@Version:	1.6

@History:	V1.0 @07.01.2017 - initial release in FS 17
			V1.5 @19.11.2017 - added possibility to show objects when it is foggy - (default true)
			V1.6 @01.01.2018 - added possibility to show objects when it is rainy - (default true)

@Usage:

	<timedVisibilitys>
		<timedVisibility index="0>2|3|2" eveningTime="19" morningTime="8"/>
		<timedVisibility index="0>2|2" eveningTime="17" morningTime="3" showOnFog="false"/>
		<timedVisibility index="0>0|2" eveningTime="18" morningTime="6" showOnFog="true" showOnRain="false"/>
		
		...
	</timedVisibilitys>

]]

TimedVisibility = {};

function TimedVisibility.prerequisitesPresent(specializations)
    return true; 
end;

function TimedVisibility:load(savegame)
	local count = 0;

	self.objects = {};
	
	while true do
		local xmlString = "vehicle.timedVisibilitys.timedVisibility(" .. tostring(count) .. ")";
		
		if not hasXMLProperty(self.xmlFile, xmlString) then
            break;
        end;
		
		local object = {};
		
		object.node = Utils.indexToObject(self.components, getXMLString(self.xmlFile, xmlString .. "#index"));
		
		if object.node ~= nil then
			object.eveningTime = tonumber(Utils.getNoNil(getXMLString(self.xmlFile, xmlString .. "#eveningTime"), 20));
			object.morningTime = tonumber(Utils.getNoNil(getXMLString(self.xmlFile, xmlString .. "#morningTime"), 7) - 1);
			object.showOnFog = Utils.getNoNil(getXMLBool(self.xmlFile, xmlString .. "#showOnFog"), true);
			object.showOnRain = Utils.getNoNil(getXMLBool(self.xmlFile, xmlString .. "#showOnRain"), true);
			
			table.insert(self.objects, object);
		end;
	
		count = count + 1;
	end;
	
	self.getIsFoggy = TimedVisibility.getIsFoggy;
	self.getIsRainTypeActive = TimedVisibility.getIsRainTypeActive;
	self.getShouldShowObjects = TimedVisibility.getShouldShowObjects;
end;

function TimedVisibility:getIsFoggy()
	return g_currentMission.environment.currentRain ~= nil and g_currentMission.environment.currentRain.rainTypeId == Environment.RAINTYPE_FOG;
end;

function TimedVisibility:getIsRainTypeActive()
	if g_currentMission.environment.currentRain ~= nil
        and g_currentMission.environment.currentRain.rainTypeId ~= Environment.RAINTYPE_FOG
        and g_currentMission.environment.currentRain.rainTypeId ~= Environment.RAINTYPE_CLOUDY
    then
        local rainType = g_currentMission.environment:getRainType();
        local isRainTypeActive = false;
        
        if rainType ~= nil then
            if rainType.rootNode ~= nil then
                isRainTypeActive = getVisibility(rainType.rootNode);
            end;
        end;
	
		return isRainTypeActive;
	end;
	
	return false;
end;

function TimedVisibility:getShouldShowObjects()
	for _, object in pairs(self.objects) do	
		return g_currentMission.environment.currentHour >= object.eveningTime or g_currentMission.environment.currentHour <= object.morningTime;
	end;
end;

function TimedVisibility:update(dt)
	for _, object in pairs(self.objects) do
		local shouldShowObject = self:getShouldShowObjects() or (object.showOnRain and self:getIsRainTypeActive()) or (object.showOnFog and self:getIsFoggy());
		
		setVisibility(object.node, shouldShowObject);
	end;
end;

function TimedVisibility:delete()end;
function TimedVisibility:mouseEvent(posX, posY, isDown, isUp, button)end;
function TimedVisibility:keyEvent(unicode, sym, modifier, isDown)end;
function TimedVisibility:draw()end;